@@ -47,6 +47,15 @@ sub handle_error {
     my $self = shift;
     my($error) = @_;
 
+    # for XML::LibXML > 1.69
+    if (ref $error eq 'XML::LibXML::Error') {
+        while($error->_prev) {
+            last if ($error->message =~/Unregistered error message/);
+            last if ($error->message =~/internal error/);
+            $error = $error->_prev
+        }
+        $error = $error->as_string;
+    }
     my @errors = split /\n/, $error;
 
     # strip internal error and unregistered error message
@@ -76,7 +85,7 @@ sub handle_error {
         $remedy->guess_encodings($self->guess_encodings);
         return $remedy;
     }
-    elsif ($errors[0] =~ /^input conversion failed due to input error/) {
+    elsif ($errors[0] =~ /^( error : )?input conversion failed due to input error/) {
         my $remedy = XML::Liberal::Remedy::InvalidEncoding->new($self, 0, undef, $error);
         $remedy->guess_encodings($self->guess_encodings);
         return $remedy;
@@ -117,10 +126,6 @@ sub handle_error {
         my($line) = ($1);
         return XML::Liberal::Remedy::ControlCode->new;
     }
-    elsif ($errors[0] =~ /^:(\d+): parser error : Extra content at the end of the document/m) {
-        my($line) = ($1);
-        return XML::Liberal::Remedy::ControlCode->new;
-    }
     elsif ($errors[0] =~ /^:(\d+): parser error : CData section not finished/) {
         my($line) = ($1);
         return XML::Liberal::Remedy::ControlCode->new;
@@ -145,8 +150,8 @@ sub handle_error {
         my($line) = ($1);
         return XML::Liberal::Remedy::Declaration->new;
     }
-    elsif ($errors[0] =~ /Content error in the external subset/) {
-        my($line) = $1;
+    elsif ($errors[0] =~ /:(\d+): parser error : Content error in the external subset/) {
+        my($line) = ($1);
         return XML::Liberal::Remedy::DeprecatedDTD->new;
     }
 
